from google.oauth2 import service_account
from googleapiclient import discovery
from oauth2client.file import Storage
import httplib2


class GoogleAPI:
    def __init__(self, service_account=None, credentials=None):
        self.scopes = ['https://www.googleapis.com/auth/display-video']
        self.get_service(service_account, credentials)

    def get_service(self, service_account=None, credentials=None):
        creds = False
        if service_account:
            creds = self.__get_service_from_service_account(service_account_file=service_account)
        if credentials:
            creds = self.__get_service_from_credentials(credentials_file=credentials)

        self.service = discovery.build('displayvideo', 'v1', credentials=creds)
        if not creds:
            raise ValueError("No credentials were provided.")

    def __get_service_from_service_account(self, service_account_file):
        credentials = service_account.Credentials.from_service_account_file(
            service_account_file, scopes=self.scopes)
        return credentials

    def __get_service_from_credentials(self, credentials_file):
        storage = Storage(credentials_file)
        credentials = storage.get()
        if credentials is None or credentials.invalid:
            raise ValueError(
                f"The credentials in file {credentials_file} are not valid"
            )
        return credentials.authorize(httplib2.Http())



from typing import List
from display_video_360.google_api import GoogleAPI


class DisplayVideo(GoogleAPI):

    def get_lineitems_for_advertiser(self, advertiser_id: str) -> List[dict]:
        """Gets line items and sets as a prop

        Args:
            advertiser_id (str): The advertiser id

        Returns:
            [list]: A list of all lineitems
        """
        res = self.service.advertisers().lineItems().list(advertiserId=advertiser_id).execute()

        return res.get("lineItems")

    def get_advertisers_for_partner(self, partner_id) -> List[dict]:
        """Gets all advertisers and sets on advertisers props"""
        res = self.service.advertisers().list(partnerId=partner_id).execute()
        self.advertisers = res.get("advertisers")
        return self.advertisers



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="display-video-360",
    version="0.0.1",
    packages=setuptools.find_packages(),
    long_description_content_type="text/markdown",
    long_description=long_description,
    python_requires=">=3.7",
    install_requires=[
        "google-api-python-client",
        "httplib2",
        "oauth2client"
    ],
    url='https://github.com/baspenny/display-video-360'
)
